@@ -7,31 +7,36 @@
 
 \if EMIT_LICENCE
 
-    ========== licence begin  PERL_STANDARD
-    Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of either the Artistic License, as
-    specified in the Perl README file or the GNU General Public License
+    modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 2
     of the License, or (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
 
+
 \endif
 */
 
 #include "dbdimp.h"
 #include <stdarg.h>
+#ifdef _WIN32
+#include "malloc.h"
+#else
+#include "alloca.h"
+#endif
 
 DBISTATE_DECLARE;
 
